@@ -245,10 +245,12 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
     compiler->createFileManager(OverlayFS);
     compiler->createSourceManager(compiler->getFileManager());
 
+    // Calling ResetAllOptionOccurrences as WA for issue from here:
+    // https://reviews.llvm.org/D66324?id=219733#1680231
+    llvm::cl::ResetAllOptionOccurrences();
     // Create compiler invocation from user args before trickering with it
     clang::CompilerInvocation::CreateFromArgs(compiler->getInvocation(),
-                                              optionsParser.beginArgs(),
-                                              optionsParser.endArgs(), *Diags);
+                                              optionsParser.args(), *Diags);
 
     // Configure our handling of diagnostics.
     ProcessWarningOptions(*Diags, compiler->getDiagnosticOpts());
